@@ -24,6 +24,9 @@ class RedisLock(object):
         flag = self.conn.setnx(self.lock_key, self.worker_name)
         if flag:
             self.conn.expireat(self.lock_key, expire_at)
+        elif self.conn.get(self.lock_key) == self.worker_name:
+            flag = True
+            self.conn.expireat(self.lock_key, expire_at)
         return flag
 
     def release(self):
@@ -34,3 +37,7 @@ class RedisLock(object):
     
     def __exit__(self, *args, **kwargs):
         self.release()
+
+    def renew(self):
+        expire_at = int(time.time() + self.timeout)
+        self.conn.expireat(self.lock_key, expire_at)
